From 6eea044a734fc53353deaa973df6f70096160435 Mon Sep 17 00:00:00 2001
From: Bharath Rupireddy <bharath.rupireddyforpostgres@gmail.com>
Date: Sun, 14 Nov 2021 02:29:04 +0000
Subject: [PATCH v2] add log messages equivalents of ps display activitymsgs

---
 src/backend/access/transam/xlog.c     | 6 ++++++
 src/backend/postmaster/pgarch.c       | 8 ++++----
 src/backend/replication/basebackup.c  | 3 +++
 src/backend/replication/walreceiver.c | 8 ++++++++
 src/backend/replication/walsender.c   | 4 ++++
 5 files changed, 25 insertions(+), 4 deletions(-)

diff --git a/src/backend/access/transam/xlog.c b/src/backend/access/transam/xlog.c
index e073121a7e..3a62b4c745 100644
--- a/src/backend/access/transam/xlog.c
+++ b/src/backend/access/transam/xlog.c
@@ -3791,6 +3791,9 @@ XLogFileRead(XLogSegNo segno, int emode, TimeLineID tli,
 					 xlogfname);
 			set_ps_display(activitymsg);
 
+			ereport(DEBUG1,
+					(errmsg_internal("waiting for %s", xlogfname)));
+
 			if (!RestoreArchivedFile(path, xlogfname,
 									 "RECOVERYXLOG",
 									 wal_segment_size,
@@ -3833,6 +3836,9 @@ XLogFileRead(XLogSegNo segno, int emode, TimeLineID tli,
 				 xlogfname);
 		set_ps_display(activitymsg);
 
+		ereport(DEBUG1,
+				(errmsg_internal("recovering %s", xlogfname)));
+
 		/* Track source of data in assorted state variables */
 		readSource = source;
 		XLogReceiptSource = source;
diff --git a/src/backend/postmaster/pgarch.c b/src/backend/postmaster/pgarch.c
index 3b33e01d95..abfe451dbe 100644
--- a/src/backend/postmaster/pgarch.c
+++ b/src/backend/postmaster/pgarch.c
@@ -547,14 +547,14 @@ pgarch_archiveXlog(char *xlog)
 	}
 	*dp = '\0';
 
-	ereport(DEBUG3,
-			(errmsg_internal("executing archive command \"%s\"",
-							 xlogarchcmd)));
-
 	/* Report archive activity in PS display */
 	snprintf(activitymsg, sizeof(activitymsg), "archiving %s", xlog);
 	set_ps_display(activitymsg);
 
+	ereport(DEBUG1,
+			(errmsg_internal("executing archive command \"%s\" for archving %s",
+							 xlogarchcmd, xlog)));
+
 	rc = system(xlogarchcmd);
 	if (rc != 0)
 	{
diff --git a/src/backend/replication/basebackup.c b/src/backend/replication/basebackup.c
index ec0485705d..bc173bfe8e 100644
--- a/src/backend/replication/basebackup.c
+++ b/src/backend/replication/basebackup.c
@@ -881,6 +881,9 @@ SendBaseBackup(BaseBackupCmd *cmd)
 		set_ps_display(activitymsg);
 	}
 
+	ereport(DEBUG1,
+			(errmsg_internal("sending backup \"%s\"", opt.label)));
+
 	/* Create a basic basebackup sink. */
 	sink = bbsink_copytblspc_new();
 
diff --git a/src/backend/replication/walreceiver.c b/src/backend/replication/walreceiver.c
index 7a7eb3784e..f0062aa615 100644
--- a/src/backend/replication/walreceiver.c
+++ b/src/backend/replication/walreceiver.c
@@ -712,6 +712,10 @@ WalRcvWaitForStartPosition(XLogRecPtr *startpoint, TimeLineID *startpointTLI)
 				 LSN_FORMAT_ARGS(*startpoint));
 		set_ps_display(activitymsg);
 	}
+
+	ereport(DEBUG1,
+			(errmsg_internal("restarting at %X/%X",
+							 LSN_FORMAT_ARGS(*startpoint))));
 }
 
 /*
@@ -1000,6 +1004,10 @@ XLogWalRcvFlush(bool dying, TimeLineID tli)
 			set_ps_display(activitymsg);
 		}
 
+		ereport(DEBUG1,
+				(errmsg_internal("streaming %X/%X",
+								  LSN_FORMAT_ARGS(LogstreamResult.Write))));
+
 		/* Also let the primary know that we made some progress */
 		if (!dying)
 		{
diff --git a/src/backend/replication/walsender.c b/src/backend/replication/walsender.c
index 7950afb173..e04bab54c9 100644
--- a/src/backend/replication/walsender.c
+++ b/src/backend/replication/walsender.c
@@ -2948,6 +2948,10 @@ retry:
 				 LSN_FORMAT_ARGS(sentPtr));
 		set_ps_display(activitymsg);
 	}
+
+	ereport(DEBUG1,
+			(errmsg_internal("streaming %X/%X",
+							  LSN_FORMAT_ARGS(sentPtr))));
 }
 
 /*
-- 
2.25.1

